@@ -12,7 +12,7 @@ class AutoSurpriseKNNBaseline(AlgorithmBase):
 
     def _objective(self, params):
         loss = self._hyperopt(params)
-        self._result_logger.append_results(loss)
+        self._result_logger.append_results(loss, params)
 
         return {
             'loss': loss,
