@@ -18,7 +18,7 @@ class AutoSurpriseNormalPredictor(AlgorithmBase):
 
     def _objective(self):
         loss = self._hyperopt()
-        self._result_logger.append_results(loss)
+        self._result_logger.append_results(loss, None)
 
         return {
             'loss': loss,
